@@ -475,7 +475,7 @@ class Wizard(ubiquity.frontend.gtk_ui.Wizard):
 
     def do_mythtv_setup(self,widget):
         """Spawn MythTV-Setup binary."""
-        os.seteuid(0)
+        regain_privileges()
         execute("/usr/share/ubiquity/mythbuntu-setup")
         drop_privileges()
 
